Documentation
¶
Overview ¶
Package xzwriter provides a WriteCloser XZWriter that pipes through an external XZ compressor.
Expects the Tukaani XZ tool in $PATH. See the XZ Utils home page: <http://tukaani.org/xz/>
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type XZWriter ¶
type XZWriter struct {
// contains filtered or unexported fields
}
XZWriter is a WriteCloser that wraps a writer around an XZ compressor.
func NewWithContext ¶
NewWithContext returns an XZWriter, wrapping the writer w. The context may be used to cancel or timeout the external compressor process.
The context can be used to kill the external process early. You still need to call Close() to clean up ressources. Alternatively you may call Close() prematurely.
Click to show internal directories.
Click to hide internal directories.